import { defineNuxtModule, addVitePlugin, addWebpackPlugin } from '@nuxt/kit';
import vitePluginStylelint from 'vite-plugin-stylelint';
import StylelintWebpackPlugin from 'stylelint-webpack-plugin';

const name = "@nuxtjs/stylelint-module";
const version = "5.0.0";

const module = defineNuxtModule({
  meta: {
    name,
    version,
    configKey: "stylelint",
    compatibility: {
      bridge: true
    }
  },
  defaults: (nuxt) => ({
    cache: true,
    include: [`${nuxt.options.srcDir}/**/*.{css,scss,sass,less,styl,vue}`],
    exclude: ["**/node_modules/**", "virtual:", nuxt.options.buildDir],
    stylelintPath: "stylelint",
    formatter: "string",
    lintOnStart: true,
    emitWarning: true,
    emitError: true,
    failOnWarning: false,
    failOnError: true
  }),
  setup(options, nuxt) {
    if (!nuxt.options.dev) {
      return;
    }
    nuxt.hooks.hookOnce("builder:watch", (_, path) => {
    });
    addVitePlugin(vitePluginStylelint(options), { server: false });
    addWebpackPlugin(new StylelintWebpackPlugin({
      ...options,
      context: nuxt.options.srcDir,
      files: options.include,
      lintDirtyModulesOnly: !options.lintOnStart
    }), { server: false });
  }
});

export { module as default };
